<?php
class AI_Business_Chatbot_Admin {
    private $api;
    private $db;

    public function __construct() {
        $this->db = new AI_Business_Chatbot_DB();
        
        // Initialize API if key exists
        $api_key = get_option('ai_chatbot_api_key');
        if ($api_key) {
            $this->api = new AI_Business_Chatbot_API($api_key);
        }

        // Set default appearance settings if not exists
        $default_appearance = array(
            'chat_color' => '#007bff',
            'messages_color' => '#ffffff',
            'messages_border_radius' => '10',
            'chat_box_border_radius' => '15',
            'custom_css' => '',
            'icon_type' => 'default',
            'icon_size' => '60',
            'chat_box_width' => '350',
            'chat_box_height' => '500',
            'user_message_font_size' => '14',
            'bot_message_font_size' => '14',
            'header_font_size' => '16',
            'bot_message_bg' => '#f1f1f1'
        );
        
        $current_appearance = get_option('ai_chatbot_appearance', array());
        if (empty($current_appearance) || count(array_diff_key($default_appearance, $current_appearance)) > 0) {
            update_option('ai_chatbot_appearance', wp_parse_args($current_appearance, $default_appearance));
        }
    }

    public function enqueue_styles() {
        wp_enqueue_style(
            'ai-business-chatbot-admin',
            AI_BUSINESS_CHATBOT_PLUGIN_URL . 'admin/css/admin.css',
            array(),
            AI_BUSINESS_CHATBOT_VERSION
        );
    }

    public function enqueue_scripts() {
        // Enqueue the color picker
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_script('wp-color-picker');
        
        // Your existing script enqueue
        wp_enqueue_script(
            'ai-business-chatbot-admin',
            AI_BUSINESS_CHATBOT_PLUGIN_URL . 'admin/js/admin.js',
            array('jquery', 'wp-color-picker'),  // Add wp-color-picker as a dependency
            AI_BUSINESS_CHATBOT_VERSION,
            true
        );

        wp_localize_script('ai-business-chatbot-admin', 'aiChatbotAdmin', array(
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('ai_chatbot_admin_nonce')
        ));
    }

    public function add_plugin_admin_menu() {
        // Main menu item
        add_menu_page(
            'AI Business Chatbot',
            'AI Chatbot',
            'manage_options',
            'ai-business-chatbot',
            array($this, 'display_plugin_admin_page'),
            'dashicons-format-chat',
            30
        );

        // Submenu items
        add_submenu_page(
            'ai-business-chatbot',
            'AI Business Chatbot',  // Changed from 'AI Business Chatbot'
            'Account',  // Changed from 'AI Chatbot'
            'manage_options',
            'ai-business-chatbot',  // Same as parent to make it the default page
            array($this, 'display_plugin_admin_page')
        );

        add_submenu_page(
            'ai-business-chatbot',
            'Settings',
            'Settings',
            'manage_options',
            'ai-business-chatbot-settings',
            array($this, 'display_plugin_settings_page')
        );
    }

    public function register_settings() {
        register_setting('ai_chatbot_settings', 'ai_chatbot_api_key');
        register_setting('ai_chatbot_settings', 'ai_chatbot_instructions');
        register_setting('ai_chatbot_settings', 'ai_chatbot_selected_model');
        register_setting('ai_chatbot_settings', 'ai_chatbot_display_mode');
        
        register_setting('ai_chatbot_settings', 'ai_chatbot_appearance', array(
            'type' => 'array',
            'default' => array(
                'chat_color' => '#007bff',
                'messages_color' => '#ffffff',
                'messages_border_radius' => '10',
                'chat_box_border_radius' => '15',
                'custom_css' => ''
            ),
            'sanitize_callback' => array($this, 'sanitize_appearance_settings')
        ));

        register_setting('ai_chatbot_settings', 'ai_chatbot_chat_title', array(
            'type' => 'string',
            'default' => 'Chat Support',
            'sanitize_callback' => 'sanitize_text_field'
        ));

        // Add redirect after settings save
        add_action('admin_init', array($this, 'settings_save_redirect'));
    }

    public function settings_save_redirect() {
        // Check if settings were saved
        if (isset($_GET['settings-updated']) && $_GET['settings-updated'] == 'true' && 
            isset($_GET['page']) && $_GET['page'] == 'ai-business-chatbot-settings') {
            
            // Redirect to main plugin page (Account page)
            wp_redirect(admin_url('admin.php?page=ai-business-chatbot'));
            exit;
        }
    }

    public function sanitize_model_selection($model) {
        $available_models = get_option('ai_chatbot_available_models', array());
        
        if (!in_array($model, $available_models)) {
            add_settings_error(
                'ai_chatbot_selected_model',
                'invalid_model',
                'Selected model is not available with your current plan.'
            );
            return get_option('ai_chatbot_selected_model'); // Return previous value
        }
        
        return $model;
    }

    public function sanitize_appearance_settings($input) {
        $defaults = array(
            'chat_color' => '#007bff',
            'messages_color' => '#ffffff',
            'messages_border_radius' => '10',
            'chat_box_border_radius' => '15',
            'custom_css' => '',
            'icon_type' => 'default',
            'icon_size' => '60',
            'chat_box_width' => '350',
            'chat_box_height' => '500',
            'user_message_font_size' => '14',
            'bot_message_font_size' => '14',
            'header_font_size' => '16',
            'bot_message_bg' => '#f1f1f1',
            'custom_icon' => ''
        );

        $output = wp_parse_args($input, $defaults);
        
        // Sanitize values
        $output['chat_color'] = sanitize_hex_color($output['chat_color']);
        $output['messages_color'] = sanitize_hex_color($output['messages_color']);
        $output['messages_border_radius'] = absint($output['messages_border_radius']);
        $output['chat_box_border_radius'] = absint($output['chat_box_border_radius']);
        $output['custom_css'] = sanitize_textarea_field($output['custom_css']);
        $output['icon_type'] = sanitize_text_field($output['icon_type']);
        $output['icon_size'] = absint($output['icon_size']);
        $output['chat_box_width'] = absint($output['chat_box_width']);
        $output['chat_box_height'] = absint($output['chat_box_height']);
        $output['user_message_font_size'] = absint($output['user_message_font_size']);
        $output['bot_message_font_size'] = absint($output['bot_message_font_size']);
        $output['header_font_size'] = absint($output['header_font_size']);
        $output['bot_message_bg'] = sanitize_hex_color($output['bot_message_bg']);
        $output['custom_icon'] = esc_url_raw($output['custom_icon']);

        return $output;
    }

    public function display_plugin_admin_page() {
        require_once AI_BUSINESS_CHATBOT_PLUGIN_DIR . 'admin/partials/admin-display.php';
    }

    public function display_plugin_settings_page() {
        require_once AI_BUSINESS_CHATBOT_PLUGIN_DIR . 'admin/partials/admin-settings.php';
    }

    public function add_menu_pages() {
        add_menu_page(
            'AI Chatbot',
            'AI Chatbot',
            'manage_options',
            'ai-business-chatbot',
            array($this, 'render_settings_page'),
            'dashicons-format-chat',
            30
        );

        add_submenu_page(
            'ai-business-chatbot',
            'Chat Logs',
            'Chat Logs',
            'manage_options',
            'ai-chatbot-logs',
            array($this, 'render_logs_page')
        );
    }

    public function render_logs_page() {
        global $wpdb;
        
        $conversations = $wpdb->get_results("
            SELECT c.*, 
                   COUNT(m.id) as message_count,
                   MAX(m.created_at) as last_activity,
                   SUM(m.cost) as total_cost
            FROM {$wpdb->prefix}ai_chatbot_conversations c
            LEFT JOIN {$wpdb->prefix}ai_chatbot_messages m ON c.conversation_id = m.conversation_id
            GROUP BY c.conversation_id
            ORDER BY last_activity DESC
        ");

        ?>
        <div class="wrap">
            <h1>Chat Logs</h1>
            <div class="tablenav top">
                <div class="alignleft actions">
                    <select id="bulk-action-selector-top">
                        <option value="-1">Bulk Actions</option>
                        <option value="delete">Delete</option>
                    </select>
                    <input type="submit" class="button action" value="Apply">
                </div>
            </div>
            <table class="wp-list-table widefat fixed striped">
                <thead>
                    <tr>
                        <th scope="col" class="manage-column column-cb check-column">
                            <input type="checkbox">
                        </th>
                        <th>Conversation ID</th>
                        <th>Messages</th>
                        <th>Last Activity</th>
                        <th>Total Cost</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($conversations as $conversation): ?>
                        <tr>
                            <td><input type="checkbox" name="conversation[]" value="<?php echo esc_attr($conversation->conversation_id); ?>"></td>
                            <td>
                                <a href="#" class="view-conversation" data-id="<?php echo esc_attr($conversation->conversation_id); ?>">
                                    <?php echo esc_html($conversation->conversation_id); ?>
                                </a>
                            </td>
                            <td><?php echo esc_html($conversation->message_count); ?></td>
                            <td><?php echo esc_html(human_time_diff(strtotime($conversation->last_activity), current_time('timestamp'))); ?> ago</td>
                            <td>$<?php echo number_format($conversation->total_cost, 5); ?></td>
                            <td>
                                <button class="button view-conversation" data-id="<?php echo esc_attr($conversation->conversation_id); ?>">View</button>
                                <button class="button delete-conversation" data-id="<?php echo esc_attr($conversation->conversation_id); ?>">Delete</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <div id="conversation-modal" class="modal">
            <div class="modal-content">
                <span class="close">&times;</span>
                <h2>Conversation Details</h2>
                <div class="conversation-messages"></div>
            </div>
        </div>
        <?php
    }
}