<?php
class AI_Business_Chatbot_API {
    private $api_key;
    private $api_url = 'https://quickworkspace.ai/api/account';
    
    public function __construct($api_key) {
        $this->api_key = $api_key;
    }

    public function validate_and_fetch_account_data() {
        $response = wp_remote_get($this->api_url, array(
            'headers' => array(
                'X-Api-Key' => $this->api_key,
                'Accept' => 'application/json'
            )
        ));

        if (is_wp_error($response)) {
            return array(
                'success' => false,
                'message' => $response->get_error_message()
            );
        }

        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);

        if (empty($data)) {
            return array(
                'success' => false,
                'message' => 'Invalid API response'
            );
        }

        // Save API key and workspace ID to wp_options
        update_option('ai_chatbot_api_key', $this->api_key);
        update_option('ai_chatbot_workspace_id', $data['workspace']['id']);

        // Extract available models from the first workspace's subscription plan config
        $available_models = array();
        if (!empty($data['workspace']['subscription']['plan']['config']['models'])) {
            foreach ($data['workspace']['subscription']['plan']['config']['models'] as $model => $is_available) {
                if ($is_available === true) {
                    $available_models[] = $model;
                }
            }
        }
        update_option('ai_chatbot_available_models', $available_models);

        // If no model is selected yet, select the first available one
        if (!get_option('ai_chatbot_selected_model') && !empty($available_models)) {
            update_option('ai_chatbot_selected_model', $available_models[0]);
        }

        // Extract required information
        $account_data = array(
            'workspace_id' => $data['workspace']['id'],
            'workspace_name' => $data['workspace']['name'],
            'user' => array(
                'first_name' => $data['first_name'],
                'last_name' => $data['last_name'],
                'email' => $data['email']
            ),
            'total_credit_count' => $data['workspace']['total_credit_count'],
            'usage_count' => $data['workspace']['subscription']['usage_count'],
            'credit_percentage' => $data['workspace']['subscription']['credit_percentage'],
            'plan_title' => $data['workspace']['subscription']['plan']['title'],
            'plan_price' => $data['workspace']['subscription']['plan']['price'],
            'plan_billing_cycle' => $data['workspace']['subscription']['plan']['billing_cycle'],
            'available_models' => $available_models
        );

        return array(
            'success' => true,
            'data' => $account_data
        );
    }

    private function extract_available_models($models_data) {
        $available_models = array();
        
        foreach ($models_data as $model => $is_available) {
            if ($is_available === true) {
                $available_models[] = $model;
            }
        }

        return $available_models;
    }

    public function get_conversation_messages() {
        check_ajax_referer('ai_chatbot_admin_nonce', 'nonce');
        
        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized');
        }

        global $wpdb;
        $conversation_id = sanitize_text_field($_POST['conversation_id']);
        
        $messages = $wpdb->get_results($wpdb->prepare("
            SELECT *
            FROM {$wpdb->prefix}ai_chatbot_messages
            WHERE conversation_id = %s
            ORDER BY created_at ASC
        ", $conversation_id));
        
        wp_send_json_success($messages);
    }

    public function delete_conversation() {
        check_ajax_referer('ai_chatbot_admin_nonce', 'nonce');
        
        if (!current_user_can('manage_options')) {
            wp_send_json_error('Unauthorized');
        }

        global $wpdb;
        $conversation_id = sanitize_text_field($_POST['conversation_id']);
        
        $wpdb->delete($wpdb->prefix . 'ai_chatbot_messages', ['conversation_id' => $conversation_id]);
        $wpdb->delete($wpdb->prefix . 'ai_chatbot_conversations', ['conversation_id' => $conversation_id]);
        
        wp_send_json_success();
    }
}