<?php
class AI_Business_Chatbot_Chatting {
    private $api_url = 'https://quickworkspace.ai/api/ai/conversations/';
    private $last_parent_id = null;

    public function send_message($conversation_id, $message, $parent_id = null) {
        global $wpdb;
        
        $api_key = get_option('ai_chatbot_api_key');
        $workspace_id = get_option('ai_chatbot_workspace_id');
        $selected_model = get_option('ai_chatbot_selected_model', 'gpt-4');
        $instructions = get_option('ai_chatbot_instructions', '');

        // Get the parent_id from the latest assistant message in this conversation
        $latest_parent_id = $wpdb->get_var($wpdb->prepare(
            "SELECT parent_id 
            FROM {$wpdb->prefix}ai_chatbot_messages 
            WHERE conversation_id = %s 
            AND role = 'assistant' 
            ORDER BY created_at DESC 
            LIMIT 1",
            $conversation_id
        ));

        // Combine message and instructions in the content
        $content = $message;
        if (!empty($instructions)) {
            $content = $instructions . "\n\n" . $message;
        }

        // Only use parent_id if not first message
        $request_body = array(
            'model' => $selected_model,
            'content' => $content
        );

        if ($latest_parent_id) {
            $request_body['parent_id'] = $latest_parent_id;
        }

        if (!$api_key || !$workspace_id || !$conversation_id) {
            return array(
                'success' => false,
                'message' => 'Missing configuration'
            );
        }

        // Save user message first
        $user_message_data = array(
            'id' => wp_generate_uuid4(),
            'parent_id' => $parent_id,
            'role' => 'user',
            'content' => $message,
            'cost' => 0
        );
        $this->save_message($conversation_id, $user_message_data);

        $url = $this->api_url . $conversation_id . '/messages';
        
        error_log('Request Body: ' . json_encode($request_body));

        $response = wp_remote_post($url, array(
            'headers' => array(
                'X-Workspace-Id' => $workspace_id,
                'X-Api-Key' => $api_key,
                'Accept' => 'text/plain',
                'Content-Type' => 'application/json'
            ),
            'body' => json_encode($request_body),
            'timeout' => 60,
            'data_format' => 'body'
        ));

        if (is_wp_error($response)) {
            error_log('API Error: ' . $response->get_error_message());
            return array(
                'success' => false,
                'message' => $response->get_error_message()
            );
        }

        $response_code = wp_remote_retrieve_response_code($response);
        $response_body = wp_remote_retrieve_body($response);

        error_log('API Response Code: ' . $response_code);
        error_log('API Response Body: ' . $response_body);

        if ($response_code !== 200) {
            return array(
                'success' => false,
                'message' => 'API Error: ' . $response_code . ' - ' . $response_body
            );
        }

        if (!empty($response_body)) {
            $parsed_response = $this->parse_response($response_body);
            
            // Save assistant message
            $assistant_message_data = array(
                'id' => $parsed_response['message_id'],
                'parent_id' => $user_message_data['id'], // Link to user message
                'role' => 'assistant',
                'content' => $parsed_response['content'],
                'cost' => 0.002 // You may want to get this from the API response
            );
            $this->save_message($conversation_id, $assistant_message_data);

            return array(
                'success' => true,
                'content' => $parsed_response['content'],
                'message_id' => $parsed_response['message_id'],
                'parent_id' => $parsed_response['parent_id']
            );
        }

        return array(
            'success' => false,
            'message' => 'Empty response from API'
        );
    }

    private function save_message($conversation_id, $message_data) {
        global $wpdb;
        
        $data = array(
            'conversation_id' => $conversation_id,
            'message_id' => $message_data['id'],
            'parent_id' => $message_data['parent_id'],
            'role' => $message_data['role'],
            'content' => $message_data['content'],
            'cost' => $message_data['cost'],
            'created_at' => current_time('mysql')
        );

        $wpdb->insert($wpdb->prefix . 'ai_chatbot_messages', $data);

        // Update the last parent ID in conversations table only for assistant messages
        if ($message_data['role'] === 'assistant') {
            $wpdb->update(
                $wpdb->prefix . 'ai_chatbot_conversations',
                array('last_parent_id' => $message_data['id']),
                array('conversation_id' => $conversation_id)
            );
        }
    }

    private function parse_response($response_body) {
        // Initialize variables
        $content = '';
        $message_id = '';
        $parent_id = '';

        // Split the response into lines
        $lines = explode("\n", $response_body);
        
        foreach ($lines as $line) {
            if (strpos($line, 'data: {') === 0) {
                // Parse JSON data
                $json_str = substr($line, 6); // Remove 'data: ' prefix
                $data = json_decode($json_str, true);
                
                if ($data && isset($data['id']) && $data['role'] === 'assistant') {
                    $message_id = $data['id'];
                    $content = $data['content'];
                    $parent_id = $data['parent_id'];
                    break;
                }
            }
        }

        return array(
            'content' => $content,
            'message_id' => $message_id,
            'parent_id' => $parent_id
        );
    }
} 